# tagesschau
Die Tagesschau ist eine Nachrichtensendung der ARD (Abkürzung für Arbeitsgemeinschaft der öffentlich-rechtlichen Rundfunkanstalten der Bundesrepublik Deutschland), die von ARD-aktuell in Hamburg produziert und mehrmals täglich ausgestrahlt wird. ARD-aktuell ist seit 1977 die zentrale Fernsehnachrichtenredaktion der ARD, bei welcher es sich wiederum um einen Rundfunkverbund handelt, der aus den Landesrundfunkanstalten und der Deutschen Welle besteht. <br><br> Über die hier dokumentierte API stehen auf [www.tagesschau.de](https://www.tagesschau.de) aktuelle Nachrichten und Medienbeiträge im JSON-Format zur Verfügung. <br><br> **Achtung:** Die Nutzung der Inhalte für den privaten, nicht-kommerziellen Gebrauch ist gestattet, die Veröffentlichung hingegen nicht - mit Ausnahme von Angeboten, die explizit unter der CC-Lizenz stehen (https://tagesschau.de/creativecommons). Es ist unzulässig, mehr als 60 Abrufe pro Stunde zu tätigen.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.1
- Package version: 0.2.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://github.com/AndreasFischer1985/tagesschau-api](https://github.com/AndreasFischer1985/tagesschau-api)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[tagesschau]
```

### poetry install

```sh
poetry add deutschland -E tagesschau
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import tagesschau
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import tagesschau
from pprint import pprint
from deutschland.tagesschau.api import channels_api
from deutschland.tagesschau.model.channels_response import ChannelsResponse
# Defining the host is optional and defaults to https://www.tagesschau.de
# See configuration.py for a list of all supported configuration parameters.
configuration = tagesschau.Configuration(
    host = "https://www.tagesschau.de"
)



# Enter a context with an instance of the API client
with tagesschau.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = channels_api.ChannelsApi(api_client)

    try:
        # Aktuelle Kanäle
        api_response = api_instance.channels()
        pprint(api_response)
    except tagesschau.ApiException as e:
        print("Exception when calling ChannelsApi->channels: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://www.tagesschau.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ChannelsApi* | [**channels**](docs/ChannelsApi.md#channels) | **GET** /api2u/channels/ | Aktuelle Kanäle
*HomepageApi* | [**homepage**](docs/HomepageApi.md#homepage) | **GET** /api2u/homepage/ | Ausgewählte aktuelle Nachrichten und Eilmeldungen
*NewsApi* | [**news**](docs/NewsApi.md#news) | **GET** /api2u/news/ | Aktuelle Nachrichten und Eilmeldungen
*SearchApi* | [**search**](docs/SearchApi.md#search) | **GET** /api2u/search/ | Suche


## Documentation For Models

 - [ChannelsResponse](docs/ChannelsResponse.md)
 - [ChannelsResponseChannelsInner](docs/ChannelsResponseChannelsInner.md)
 - [HomepageResponse](docs/HomepageResponse.md)
 - [HomepageResponseNewsInner](docs/HomepageResponseNewsInner.md)
 - [HomepageResponseRegionalInner](docs/HomepageResponseRegionalInner.md)
 - [MultimediaResponse](docs/MultimediaResponse.md)
 - [NewsResponse](docs/NewsResponse.md)
 - [NewsResponseNewsInner](docs/NewsResponseNewsInner.md)
 - [SearchResponse](docs/SearchResponse.md)
 - [SearchResponseSearchResultsInner](docs/SearchResponseSearchResultsInner.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

andreasfischer1985@web.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in tagesschau.apis and tagesschau.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.tagesschau.api.default_api import DefaultApi`
- `from deutschland.tagesschau.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import tagesschau
from deutschland.tagesschau.apis import *
from deutschland.tagesschau.models import *
```

